ChatRequest

Struct ChatRequest 

pub struct ChatRequest {
Show 17 fields pub client: DeepSeekClient, pub messages: Vec<ChatMessage>, pub model: String, pub thinking: Option<Thinking>, pub reasoning_effort: Option<ReasoningEffort>, pub max_tokens: Option<u32>, pub response_format: Option<ResponseFormat>, pub stop: Option<Stop>, pub stream: Option<bool>, pub stream_options: Option<StreamOptions>, pub temperature: Option<f64>, pub top_p: Option<f64>, pub tools: Vec<Tool>, pub tool_choice: Option<ToolChoice>, pub logprobs: Option<bool>, pub top_logprobs: Option<u32>, pub user_id: Option<String>,
}
Chat completion request body.

Fields

client: DeepSeekClientmessages: Vec<ChatMessage>

A list of messages comprising the conversation so far.

model: String

Possible values: [deepseek-v4-flash, deepseek-v4-pro]

ID of the model to use.

thinking: Option<Thinking>

Controls the switch between thinking and non-thinking mode.

reasoning_effort: Option<ReasoningEffort>

Possible values: [high, max]

Controls the reasoning effort of the model. The default effort is high for regular requests; for some complex agent requests (such as Claude Code, OpenCode), effort is automatically set to max. For compatibility, low and medium are mapped to high, and xhigh is mapped to max.

max_tokens: Option<u32>

The maximum number of tokens that can be generated in the chat completion.

The total length of input tokens and generated tokens is limited by the model’s context length.

For the value range and default value, please refer to the documentation.

response_format: Option<ResponseFormat>

An object specifying the format that the model must output. Setting to { “type”: “json_object” } enables JSON Output, which guarantees the message the model generates is valid JSON.

Important: When using JSON Output, you must also instruct the model to produce JSON yourself via a system or user message. Without this, the model may generate an unending stream of whitespace until the generation reaches the token limit, resulting in a long-running and seemingly “stuck” request. Also note that the message content may be partially cut off if finish_reason=“length”, which indicates the generation exceeded max_tokens or the conversation exceeded the max context length.

stop: Option<Stop>

Up to 16 sequences where the API will stop generating further tokens.

stream: Option<bool>

If set, partial message deltas will be sent. Tokens will be sent as data-only server-sent events (SSE) as they become available, with the stream terminated by a `data: [DONE]`` message.

stream_options: Option<StreamOptions>

Options for streaming response. Only set this when you set stream: true.

temperature: Option<f64>

Possible values: <= 2

Default value: 1

What sampling temperature to use, between 0 and 2. Higher values like 0.8 will make the output more random, while lower values like 0.2 will make it more focused and deterministic. We generally recommend altering this or top_p but not both.

top_p: Option<f64>

Possible values: <= 1

Default value: 1

An alternative to sampling with temperature, called nucleus sampling, where the model considers the results of the tokens with top_p probability mass. So 0.1 means only the tokens comprising the top 10% probability mass are considered.

We generally recommend altering this or temperature but not both.

tools: Vec<Tool>

A list of tools the model may call. Currently, only functions are supported as a tool. Use this to provide a list of functions the model may generate JSON inputs for. A max of 128 functions are supported.

tool_choice: Option<ToolChoice>

Controls which (if any) tool is called by the model. none means the model will not call any tool and instead generates a message. auto means the model can pick between generating a message or calling one or more tools. required means the model must call one or more tools. Specifying a particular tool via {"type": "function", "function": {"name": "my_function"}} forces the model to call that tool. none is the default when no tools are present. auto is the default if tools are present.

logprobs: Option<bool>

Whether to return log probabilities of the output tokens or not. If true, returns the log probabilities of each output token returned in the content of message.

top_logprobs: Option<u32>

Possible values: <= 20

An integer between 0 and 20 specifying the number of most likely tokens to return at each token position, each with an associated log probability. logprobs must be set to true if this parameter is used.

user_id: Option<String>

A custom user_id. Allowed character set is [a-zA-Z0-9\-_], with a maximum length of 512. Do not include user privacy information in the user_id. user_id can be used to distinguish user identities on your side to help us with content safety review. user_id can be used for KVCache isolation for privacy management. user_id can be used for scheduling isolation of users on your business side. For more details on the user_id parameter, please refer to Rate Limit & Isolation