pub struct ToolFunctionDefinition {
pub description: String,
pub name: String,
pub parameters: Option<Value>,
}Expand description
Tool function definition.
Fields
description: StringA description of what the function does, used by the model to choose when and how to call the function.
name: StringThe name of the function to be called. Must be a-z, A-Z, 0-9, or contain underscores and dashes, with a maximum length of 64.
parameters: Option<Value>The parameters the functions accepts, described as a JSON Schema object. See the Tool Calls Guide for examples, and the JSON Schema reference for documentation about the format.
Omitting parameters defines a function with an empty parameter list.