pub struct Usage {
pub completion_tokens: u64,
pub prompt_tokens: u64,
pub prompt_cache_hit_tokens: u64,
pub prompt_cache_miss_tokens: u64,
pub total_tokens: u64,
pub completion_tokens_details: Option<CompletionTokensDetails>,
}Expand description
Token usage statistics for a request.
Fields
completion_tokens: u64Number of tokens in the generated completion.
prompt_tokens: u64Number of tokens in the prompt. It equals prompt_cache_hit_tokens + prompt_cache_miss_tokens.
prompt_cache_hit_tokens: u64Number of tokens in the prompt that hits the context cache.
prompt_cache_miss_tokens: u64Number of tokens in the prompt that misses the context cache.
total_tokens: u64Total number of tokens used in the request (prompt + completion).
completion_tokens_details: Option<CompletionTokensDetails>Breakdown of tokens used in a completion.