pub struct BetaToolFunctionDefinition {
pub description: String,
pub name: String,
pub parameters: Option<Value>,
pub strict: Option<bool>,
}Expand description
Tool function definition for beta chat requests.
Fields
description: Stringname: Stringparameters: Option<Value>strict: Option<bool>(Beta) Default value: false
If set to true, the API will use strict-mode for the tool calls to ensure the output always complies with the function’s JSON schema. This is a Beta feature, for more details please refer to Tool Calls Guide