pub struct CompletionChoice {
pub finish_reason: FinishReason,
pub index: u64,
pub text: String,
pub logprobs: Option<Logprobs>,
}Expand description
Completion choice the model generated for the input prompt.
Fields
finish_reason: FinishReasonPossible values: [stop, length, content_filter, insufficient_system_resource]
The reason the model stopped generating tokens.
This will be stop if the model hit a natural stop point or a provided stop sequence,
length if the maximum number of tokens specified in the request was reached,
content_filter if content was omitted due to a flag from our content filters,
or insufficient_system_resource if the request is interrupted due to insufficient resource of the inference system.
index: u64text: Stringlogprobs: Option<Logprobs>Trait Implementations
Sourceimpl Clone for CompletionChoice
impl Clone for CompletionChoice
Sourcefn clone(&self) -> CompletionChoice
fn clone(&self) -> CompletionChoice
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CompletionChoice
impl Debug for CompletionChoice
Sourceimpl<'de> Deserialize<'de> for CompletionChoice
impl<'de> Deserialize<'de> for CompletionChoice
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for CompletionChoice
impl PartialEq for CompletionChoice
Sourcefn eq(&self, other: &CompletionChoice) -> bool
fn eq(&self, other: &CompletionChoice) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CompletionChoice
impl Serialize for CompletionChoice
impl StructuralPartialEq for CompletionChoice