FIMCompletionRequest

Struct FIMCompletionRequest 

pub struct FIMCompletionRequest {
    pub client: DeepSeekClient,
    pub model: String,
    pub prompt: String,
    pub echo: Option<bool>,
    pub logprobs: Option<u32>,
    pub max_tokens: Option<u32>,
    pub stop: Option<Stop>,
    pub stream: Option<bool>,
    pub stream_options: Option<StreamOptions>,
    pub suffix: Option<String>,
    pub temperature: Option<f64>,
    pub top_p: Option<f64>,
}
FIM completion request payload.

Fields

client: DeepSeekClientmodel: String

Possible values: [deepseek-v4-pro]

ID of the model to use.

prompt: String

The prompt to generate completions for.

echo: Option<bool>

Echo back the prompt in addition to the completion

logprobs: Option<u32>

Possible values: <= 20

Include the log probabilities on the logprobs most likely output tokens, as well the chosen tokens. For example, if logprobs is 20, the API will return a list of the 20 most likely tokens. The API will always return the logprob of the sampled token, so there may be up to logprobs+1 elements in the response. The maximum value for logprobs is 20.

max_tokens: Option<u32>

The maximum number of tokens that can be generated in the completion.

stop: Option<Stop>

Up to 16 sequences where the API will stop generating further tokens. The returned text will not contain the stop sequence.

stream: Option<bool>

Whether to stream back partial progress. If set, tokens will be sent as data-only server-sent events as they become available, with the stream terminated by a · message. Example Python code.

stream_options: Option<StreamOptions>

Options for streaming response. Only set this when you set stream: true.

suffix: Option<String>

The suffix that comes after a completion of inserted text.

temperature: Option<f64>

Possible values: <= 2

Default value: 1

What sampling temperature to use, between 0 and 2. Higher values like 0.8 will make the output more random, while lower values like 0.2 will make it more focused and deterministic. We generally recommend altering this or top_p but not both.

top_p: Option<f64>

Possible values: <= 1

Default value: 1

An alternative to sampling with temperature, called nucleus sampling, where the model considers the results of the tokens with top_p probability mass. So 0.1 means only the tokens comprising the top 10% probability mass are considered. We generally recommend altering this or temperature but not both.