pub enum BetaChatMessage {
System {
content: String,
name: Option<String>,
},
User {
content: String,
name: Option<String>,
},
Assistant {
content: Option<String>,
name: Option<String>,
prefix: bool,
reasoning_content: Option<String>,
tool_calls: Option<Vec<ToolCall>>,
},
Tool {
content: String,
tool_call_id: String,
},
}Expand description
Beta chat message variants.
Variants
System
Fields
User
Fields
Assistant
Fields

name: Option<String>An optional name for the participant. Provides the model information to differentiate between participants of the same role.

prefix: bool(Beta) Set this to true to force the model to start its answer by the content of the supplied prefix in this assistant message.
You must set base_url="https://api.deepseek.com/beta" to use this feature.

reasoning_content: Option<String>(Beta) Used for the thinking mode in the Chat Prefix Completion
feature as the input for the CoT in the last assistant message.
When using this feature, the prefix parameter must be set to true.
Tool