pub struct ResponsesRequestBuilder { /* private fields */ }Expand description
Builder for ResponsesRequest.
Implementations
Sourceimpl ResponsesRequestBuilder
impl ResponsesRequestBuilder
pub fn client<VALUE: Into<DeepSeekClient>>(self, value: VALUE) -> Self
Sourcepub fn model<VALUE: Into<String>>(self, value: VALUE) -> Self
pub fn model<VALUE: Into<String>>(self, value: VALUE) -> Self
ID of the model to use. The Responses API currently only supports deepseek-v4-flash.
Sourcepub fn input<VALUE: Into<Input>>(self, value: VALUE) -> Self
pub fn input<VALUE: Into<Input>>(self, value: VALUE) -> Self
The input to the model. Either a plain string (treated as a single user message),
or a list of input items.
At least one of input and instructions is required.
Sourcepub fn instructions<VALUE: Into<String>>(self, value: VALUE) -> Self
pub fn instructions<VALUE: Into<String>>(self, value: VALUE) -> Self
A system-level instruction, inserted as the first system message of the model’s context.
Sourcepub fn reasoning<VALUE: Into<Reasoning>>(self, value: VALUE) -> Self
pub fn reasoning<VALUE: Into<Reasoning>>(self, value: VALUE) -> Self
Configuration of the thinking mode.
Sourcepub fn max_output_tokens<VALUE: Into<u32>>(self, value: VALUE) -> Self
pub fn max_output_tokens<VALUE: Into<u32>>(self, value: VALUE) -> Self
An upper bound for the number of tokens that can be generated in the response, including both the visible output tokens and the reasoning tokens.
Sourcepub fn stream<VALUE: Into<bool>>(self, value: VALUE) -> Self
pub fn stream<VALUE: Into<bool>>(self, value: VALUE) -> Self
If set to true, the response is streamed as semantic server-sent events.
The final event is response.completed / response.incomplete / response.failed
(there is no data: [DONE] message).
Sourcepub fn temperature<VALUE: Into<f64>>(self, value: VALUE) -> Self
pub fn temperature<VALUE: Into<f64>>(self, value: VALUE) -> Self
Possible values: <= 2
Default value: 1
What sampling temperature to use, between 0 and 2. Higher values like 0.8 will make the output more random, while lower values like 0.2 will make it more focused and deterministic. Has no effect in thinking mode.
Sourcepub fn top_p<VALUE: Into<f64>>(self, value: VALUE) -> Self
pub fn top_p<VALUE: Into<f64>>(self, value: VALUE) -> Self
Possible values: <= 1
Default value: 1
An alternative to sampling with temperature, called nucleus sampling. Has no effect in thinking mode.
Sourcepub fn tools<VALUE: Into<Vec<Tool>>>(self, value: VALUE) -> Self
pub fn tools<VALUE: Into<Vec<Tool>>>(self, value: VALUE) -> Self
A list of tools the model may call. Function names must be non-empty, at most 128 characters,
match ^[a-zA-Z0-9_-]+$, and be unique across all tools.
Besides function, the built-in web_search tool is supported and executed on the server side.
Sourcepub fn tool<VALUE, FROM_VALUE: Into<VALUE>>(self, item: FROM_VALUE) -> Self
pub fn tool<VALUE, FROM_VALUE: Into<VALUE>>(self, item: FROM_VALUE) -> Self
A list of tools the model may call. Function names must be non-empty, at most 128 characters,
match ^[a-zA-Z0-9_-]+$, and be unique across all tools.
Besides function, the built-in web_search tool is supported and executed on the server side.
Sourcepub fn tool_choice<VALUE: Into<ToolChoice>>(self, value: VALUE) -> Self
pub fn tool_choice<VALUE: Into<ToolChoice>>(self, value: VALUE) -> Self
Controls which (if any) tool is called by the model.
none means the model will not call any tool and instead generates a message.
auto (default) means the model can pick between generating a message or calling one or more tools.
required means the model must call one or more tools.
Specifying a particular tool via {"type": "function", "name": "my_function"} forces the model
to call that tool.
Sourcepub fn top_logprobs<VALUE: Into<u32>>(self, value: VALUE) -> Self
pub fn top_logprobs<VALUE: Into<u32>>(self, value: VALUE) -> Self
Possible values: <= 20
An integer between 0 and 20 specifying the number of most likely tokens to return at each token position, each with an associated log probability.
Sourcepub fn user<VALUE: Into<String>>(self, value: VALUE) -> Self
pub fn user<VALUE: Into<String>>(self, value: VALUE) -> Self
A custom end-user identifier, with allowed character set [a-zA-Z0-9\-_] and a maximum length
of 512. Do not include user privacy information.